==> Theophrastus-2.0.5.12380.tar.gz: Theophrastus-2.0.5.12380/Theophrastus/newsletter_extension/admin.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-
# $Id: admin.py 12366 2020-06-19 06:41:16Z Andy $
#
# Copyright (c) 2013 Nuwa Information Co., Ltd, All Rights Reserved.
#
# Licensed under the Proprietary License,
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at our web site.
#
# See the License for the specific language governing permissions and
# limitations under the License.
#
# $Author: Andy $
# $Date: 2020-06-19 15:41:16 +0900 (週五, 19 六月 2020) $
# $Revision: 12366 $

from django import forms
from django.contrib import admin
from django.utils.translation import ugettext as _
from django.conf import settings
from django.contrib.contenttypes.models import ContentType
from django.urls import reverse
from django.utils.html import format_html

from emencia.django.newsletter.models import Newsletter
from emencia.django.newsletter.admin import NewsletterAdmin

from selectable.forms import AutoCompleteWidget, AutoComboboxWidget

from Theophrastus.newsletter_extension.models import Header, Footer
from Theophrastus.newsletter_extension.forms import HeaderTinyMCEForm
from Theophrastus.newsletter_extension.forms import FooterTinyMCEForm
from Theophrastus.newsletter_extension.lookups import (
    SenderLookup, ReplyLookup, HeaderLookup, FooterLookup)

class HeaderTinyMCEAdmin(admin.ModelAdmin):
    list_display=['title']
    form = HeaderTinyMCEForm

admin.site.register(Header, HeaderTinyMCEAdmin)

class FooterTinyMCEAdmin(admin.ModelAdmin):
    list_display=['title']
    form = FooterTinyMCEForm

admin.site.register(Footer, FooterTinyMCEAdmin)

class NewsletterForm(forms.ModelForm):

    def __init__(self, *args, **kwargs):
        
        newsletterObj = Newsletter.objects.all().order_by('-id')

        if newsletterObj:
            header = newsletterObj[0].header
            footer = newsletterObj[0].footer
            if header:
                headerTitle = header.title
            else:
                headerTitle = Header.objects.first().title
            if footer:
                footerTitle = footer.title
            else:
                footerTitle = Footer.objects.first().title
            
            sender = newsletterObj[0].header_sender
            reply = newsletterObj[0].header_reply
        else:
            sender = getattr(
                settings,
                'NEWSLETTER_DEFAULT_HEADER_SENDER',
                "Nuwa<service@tracedig.com>"
            )
            reply = getattr(
                settings,
                'NEWSLETTER_DEFAULT_HEADER_REPLY',
                "Nuwa<service@tracedig.com>"
            )
            headerTitle = Header.objects.first().title
            footerTitle = Footer.objects.first().title

        super(NewsletterForm, self).__init__(*args, **kwargs)
        self.fields['header_sender'].initial = sender
        self.fields['header_reply'].initial = reply
        self.fields['header'].initial = headerTitle
        self.fields['footer'].initial = footerTitle

    content = forms.CharField(
        label=_("Content")
    )
    
    header = forms.CharField(
        label=_('header'),
        widget=AutoComboboxWidget(lookup_class=HeaderLookup),
        required=True,
    )

    footer = forms.CharField(
        label=_('footer'),
        widget=AutoComboboxWidget(lookup_class=FooterLookup),
        required=True,
    )

    header_sender = forms.CharField(
        label=_('sender'),
        widget=AutoComboboxWidget(lookup_class=SenderLookup),
        required=True,
    )

    header_reply = forms.CharField(
        label=_('reply to'),
        widget=AutoComboboxWidget(lookup_class=ReplyLookup),
        required=True,
    )

    def clean_header_reply(self):
        """
        Validate reply value.
        """
        reply = self.cleaned_data["header_reply"]
        try:
            reply.encode()
        except UnicodeEncodeError:
            raise forms.ValidationError(
                _("Incorrect value for reply, it can only include English "
                "word, number and symbol."))
        return reply

    class Meta:
        model = Newsletter
        fields = '__all__'

class NewsletterExtensionAdmin(NewsletterAdmin):
    
    list_display = ('title', 'getMailingList', 'getServer', 'status',
                'formatedSendingDate', 'formatedCreationDate',
                'formatedModificationDate',
                'historic_link', 'statistics_link')

    fieldsets = ((None, {'fields': ('title', 'subject', 
                         'header', 'footer',  
                         'content',)}),
                 (_('Receivers'), {'fields': (
                     'mailing_list', 'test_contacts',)}),
                 (_('Sending'), {'fields': ('sending_date', 'status',)}),
                 (_('Miscellaneous'), {'fields': ('server', 'header_sender',
                                                  'header_reply', 'slug'),
                                       'classes': ('collapse',)}),
                 )
    def save_model(self, request, obj, form, change):
        header = ContentType.objects.get(
            app_label="newsletter_extension", model="header")
        footer = ContentType.objects.get(
            app_label="newsletter_extension", model="footer")
        headerTitle = form.cleaned_data['header']
        footerTitle = form.cleaned_data['footer']
        headerId = Header.objects.filter(title=headerTitle)[0].id
        footerId = Footer.objects.filter(title=footerTitle)[0].id
        obj.headerContentType = header
        obj.footerContentType = footer
        obj.headerId = headerId
        obj.footerId = footerId

        return super(NewsletterExtensionAdmin, self).save_model(
            request, obj, form, change)  
    def formatedSendingDate(self, obj):
        return obj.sending_date.strftime("%Y-%m-%d %H:%M:%S")
    formatedSendingDate.short_description = _('sending date')

    def formatedCreationDate(self, obj):
        return obj.creation_date.strftime("%Y-%m-%d %H:%M:%S")
    formatedCreationDate.short_description = _('creation date')

    def formatedModificationDate(self, obj):
        return obj.modification_date.strftime("%Y-%m-%d %H:%M:%S")
    formatedModificationDate.short_description = _('modification date')

    def getMailingList(self, obj):
        if obj:
            mailingList = obj.mailing_list
            url = reverse('admin:newsletter_mailinglist_change', args=(mailingList.id,))
            
            return format_html(u"<a href='%s'>%s</a>" % (url, mailingList.name))

    def getServer(self, obj):
        if obj:
            server = obj.server
            url = reverse('admin:newsletter_smtpserver_change', args=(server.id,))
    
            return format_html(u"<a href='%s'>%s</a>" % (url, server.name))

    getMailingList.short_description = _('mailing list')
    getMailingList.allow_tags = True
    getServer.short_description = _('server')
    getServer.allow_tags = True

    class Media:
        try:
            js = [
                'js/Newsletter.js',
            ]
        except AttributeError:
            pass

    form = NewsletterForm

admin.site.unregister(Newsletter)
admin.site.register(Newsletter, NewsletterExtensionAdmin)

from emencia.django.newsletter.models import Contact
from emencia.django.newsletter.admin import ContactAdmin

class ContactTheophrastusAdmin(ContactAdmin):
    list_display = (
        'email', 'first_name', 'last_name', 'tester', 'subscriber',
        'valid', 'total_subscriptions', 'formatedCreationDate',
        'related_object_admin')#'tags', 

    def formatedCreationDate(self, obj):
        return obj.creation_date.strftime("%Y-%m-%d %H:%M:%S")
    formatedCreationDate.short_description = _('creation date')

admin.site.unregister(Contact)
admin.site.register(Contact, ContactTheophrastusAdmin)

==> Theophrastus-2.0.13.12980.tar.gz: Theophrastus-2.0.13.12980/Theophrastus/newsletter_extension/admin.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-
# $Id: admin.py 12823 2021-03-31 12:51:48Z Lavender $
#
# Copyright (c) 2013 Nuwa Information Co., Ltd, All Rights Reserved.
#
# Licensed under the Proprietary License,
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at our web site.
#
# See the License for the specific language governing permissions and
# limitations under the License.
#
# $Author: Lavender $
# $Date: 2021-03-31 20:51:48 +0800 (週三, 31 三月 2021) $
# $Revision: 12823 $

from django import forms
from django.contrib import admin
from django.utils.translation import ugettext as _
from django.conf import settings
from django.contrib.contenttypes.models import ContentType
from django.urls import reverse
from django.utils.html import format_html

from emencia.django.newsletter.models import Newsletter
from emencia.django.newsletter.admin import NewsletterAdmin

from selectable.forms import AutoCompleteWidget, AutoComboboxWidget

from Theophrastus.newsletter_extension.models import Header, Footer
from Theophrastus.newsletter_extension.forms import HeaderTinyMCEForm
from Theophrastus.newsletter_extension.forms import FooterTinyMCEForm
from Theophrastus.newsletter_extension.lookups import (
    SenderLookup, ReplyLookup, HeaderLookup, FooterLookup)

class HeaderTinyMCEAdmin(admin.ModelAdmin):
    list_display=['title']
    form = HeaderTinyMCEForm

admin.site.register(Header, HeaderTinyMCEAdmin)

class FooterTinyMCEAdmin(admin.ModelAdmin):
    list_display=['title']
    form = FooterTinyMCEForm

admin.site.register(Footer, FooterTinyMCEAdmin)

class NewsletterForm(forms.ModelForm):

    def __init__(self, *args, **kwargs):
        
        newsletterObj = Newsletter.objects.all().order_by('-id')

        if newsletterObj:
            header = newsletterObj[0].header
            footer = newsletterObj[0].footer
            if header:
                headerTitle = header.title
            else:
                headerTitle = Header.objects.first().title
            if footer:
                footerTitle = footer.title
            else:
                footerTitle = Footer.objects.first().title
            
            sender = newsletterObj[0].header_sender
            reply = newsletterObj[0].header_reply
        else:
            sender = getattr(
                settings,
                'NEWSLETTER_DEFAULT_HEADER_SENDER',
                "Nuwa<service@tracedig.com>"
            )
            reply = getattr(
                settings,
                'NEWSLETTER_DEFAULT_HEADER_REPLY',
                "Nuwa<service@tracedig.com>"
            )
            headerTitle = Header.objects.first().title
            footerTitle = Footer.objects.first().title

        super(NewsletterForm, self).__init__(*args, **kwargs)
        self.fields['header_sender'].initial = sender
        self.fields['header_reply'].initial = reply
        self.fields['header'].initial = headerTitle
        self.fields['footer'].initial = footerTitle

    content = forms.CharField(
        label=_("Content")
    )
    
    header = forms.CharField(
        label=_('header'),
        widget=AutoComboboxWidget(lookup_class=HeaderLookup),
        required=True,
    )

    footer = forms.CharField(
        label=_('footer'),
        widget=AutoComboboxWidget(lookup_class=FooterLookup),
        required=True,
    )

    header_sender = forms.CharField(
        label=_('sender'),
        widget=AutoComboboxWidget(lookup_class=SenderLookup),
        required=True,
    )

    header_reply = forms.CharField(
        label=_('reply to'),
        widget=AutoComboboxWidget(lookup_class=ReplyLookup),
        required=True,
    )

    def clean_header_reply(self):
        """
        Validate reply value.
        """
        reply = self.cleaned_data["header_reply"]
        try:
            reply.encode()
        except UnicodeEncodeError:
            raise forms.ValidationError(
                _("Incorrect value for reply, it can only include English "
                "word, number and symbol."))
        return reply

    class Meta:
        model = Newsletter
        fields = '__all__'

class NewsletterExtensionAdmin(NewsletterAdmin):
    
    list_display = ('title', 'getMailingList', 'getServer', 'status',
                'formatedSendingDate', 'formatedCreationDate',
                'formatedModificationDate',
                'historic_link', 'statistics_link')

    fieldsets = ((None, {'fields': ('title', 'subject', 
                         'header', 'footer',  
                         'content',)}),
                 (_('Receivers'), {'fields': (
                     'mailing_list', 'test_contacts',)}),
                 (_('Sending'), {'fields': ('sending_date', 'status',)}),
                 (_('Miscellaneous'), {'fields': ('server', 'header_sender',
                                                  'header_reply', 'slug'),
                                       'classes': ('collapse',)}),
                 )
    def save_model(self, request, obj, form, change):
        header = ContentType.objects.get(
            app_label="newsletter_extension", model="header")
        footer = ContentType.objects.get(
            app_label="newsletter_extension", model="footer")
        headerTitle = form.cleaned_data['header']
        footerTitle = form.cleaned_data['footer']
        headerId = Header.objects.filter(title=headerTitle)[0].id
        footerId = Footer.objects.filter(title=footerTitle)[0].id
        obj.headerContentType = header
        obj.footerContentType = footer
        obj.headerId = headerId
        obj.footerId = footerId

        return super(NewsletterExtensionAdmin, self).save_model(
            request, obj, form, change)  
    def formatedSendingDate(self, obj):
        return obj.sending_date.strftime("%Y-%m-%d %H:%M:%S")
    formatedSendingDate.short_description = _('sending date')

    def formatedCreationDate(self, obj):
        return obj.creation_date.strftime("%Y-%m-%d %H:%M:%S")
    formatedCreationDate.short_description = _('creation date')

    def formatedModificationDate(self, obj):
        return obj.modification_date.strftime("%Y-%m-%d %H:%M:%S")
    formatedModificationDate.short_description = _('modification date')

    def getMailingList(self, obj):
        if obj:
            mailingList = obj.mailing_list
            url = reverse('admin:newsletter_mailinglist_change', args=(mailingList.id,))
            
            return format_html(u"<a href='%s'>%s</a>" % (url, mailingList.name))

    def getServer(self, obj):
        if obj:
            server = obj.server
            url = reverse('admin:newsletter_smtpserver_change', args=(server.id,))
    
            return format_html(u"<a href='%s'>%s</a>" % (url, server.name))

    getMailingList.short_description = _('mailing list')
    getMailingList.allow_tags = True
    getServer.short_description = _('server')
    getServer.allow_tags = True

    class Media:
        try:
            js = [
                'js/Newsletter.js',
            ]
        except AttributeError:
            pass

    form = NewsletterForm

admin.site.unregister(Newsletter)
admin.site.register(Newsletter, NewsletterExtensionAdmin)

from emencia.django.newsletter.models import Contact
from emencia.django.newsletter.admin import ContactAdmin

class ContactTheophrastusAdmin(ContactAdmin):
    list_display = (
        'email', 'first_name', 'last_name', 'tester', 'subscriber',
        'valid', 'total_subscriptions', 'formatedCreationDate',
        'related_object_admin')#'tags', 

    def formatedCreationDate(self, obj):
        return obj.creation_date.strftime("%Y-%m-%d %H:%M:%S")
    formatedCreationDate.short_description = _('creation date')

admin.site.unregister(Contact)
admin.site.register(Contact, ContactTheophrastusAdmin)

from Theophrastus.newsletter_extension.models import BlackContact

class BlackContactAdmin(admin.ModelAdmin):
    list_display = ('email', 'reason', 'createdTime', 'source', 'mail')
    
admin.site.register(BlackContact, BlackContactAdmin)
